package org.relaxng.datatype.helpers;

import org.relaxng.datatype.*;

/**
 * Dummy implementation of {@link DatatypeBuilder}.
 * 
 * This implementation can be used for Datatypes which have no parameters.
 * Any attempt to add parameters will be rejected.
 * 
 * <p>
 * Typical usage would be:
 * <PRE><XMP>
 * class MyDatatypeLibrary implements DatatypeLibrary {
 *     ....
 *     ....
 * }
 * </XMP></PRE>
 * 
 * @author <a href="mailto:kohsuke.kawaguchi@eng.sun.com">Kohsuke KAWAGUCHI</a>
 */
public final class ParameterlessDatatypeBuilder implements DatatypeBuilder {

	/** this type object is returned for the derive method. */
	private final Datatype baseType;
	
	public ParameterlessDatatypeBuilder( Datatype baseType ) {
		this.baseType = baseType;
	}
	
	public void addParameter( String name, String strValue, ValidationContext context )
			throws DatatypeException {
		throw new DatatypeException("parameter is not supported");
	}
	
	public Datatype createDatatype() throws DatatypeException {
		return baseType;
	}
}
